# pyNRSDB
Python interface for the National Solar Radiation Database (NSRDB) made available by NREL.

Look for expansion of features in the future.

NSRDB Site: https://nsrdb.nrel.gov/
NSRDB API Documentation: https://nsrdb.nrel.gov/data-sets/api-instructions.html

References:
[1] M. Sengupta, Y. Xie, A. Lopez, A. Habte, G. Maclaurin, and J. Shelby, “The National Solar Radiation Data Base (NSRDB),” Renewable and Sustainable Energy Reviews, vol. 89, pp. 51–60, Jun. 2018, doi: 10.1016/j.rser.2018.03.003.
